@@ -43,7 +43,7 @@ sub Read
 	return unless $format;
 	my ($package,$formatstring,$plist)=@$format;
 	my $filetag= eval { $package->new($file,$findlength); }; #filelength==1 -> may return estimated length (mp3 only)
-	unless ($filetag) { warn $@ if $@; warn "can't read tags for $file\n"; return }
+	unless ($filetag) { warn $@ if $@; warn "Can't read tags for $file\n"; return }
 
 	::setlocale(::LC_NUMERIC, 'C');
 	my @taglist;
@@ -246,6 +246,7 @@ sub FMPS_hash_write
 
 sub PixFromMusicFile
 {	my ($file,$nb,$quiet)=@_;
+	if ($file=~s/:(\w+)$//) {$nb=$1} # index can be specified as argument or in the filename
 	my ($h)=Read($file,0,'embedded_pictures');
 	return unless $h;
 	my $pix= $h->{embedded_pictures};
@@ -300,10 +301,8 @@ sub Error_Message
 }
 
 package MassTag;
-use Gtk2;
-use constant
-{	TRUE  => 1, FALSE => 0,
-};
+
+use constant { TRUE  => 1, FALSE => 0, };
 
 our @FORMATS;
 our @FORMATS_user;
@@ -363,7 +362,7 @@ INIT
 # @FORMATS=@tmp;
 }
 
-use base 'Gtk2::VBox';
+use base 'Gtk2::Box';
 sub new
 {	my ($class,@IDs) = @_;
 	@IDs= ::uniq(@IDs);
@@ -601,7 +600,7 @@ sub add_selectfile_column
 sub scroll_to_entry
 {	my $ent=$_[0];
 	if (my $sw=::find_ancestor($ent,'Gtk2::Viewport'))
-	{	my ($x,$y,$w,$h)=$ent->window->get_geometry;
+	{	my ($x,$y,$w,$h)= $ent->allocation->values;
 		$sw->get_hadjustment->clamp_page($x,$x+$w);
 		$sw->get_vadjustment->clamp_page($y,$y+$h);
 	};
@@ -778,10 +777,7 @@ sub new
 	$sg->add_widget($_) for $label_format,$label_re;
 	my $bbox= Gtk2::HButtonBox->new;
 	$bbox->add($_) for $button_del, $button_add, $button_new;
-	my $sw=Gtk2::ScrolledWindow->new;
-	 $sw->set_shadow_type('etched-in');
-	 $sw->set_policy('automatic','automatic');
-	 $sw->add($treeview);
+	my $sw= ::new_scrolledwindow($treeview,'etched-in');
 	 $sw->set_size_request(150,-1); #give the list a minimum width
 	my $table= ::MakeReplaceTable('taAlCyndgL', A=>Songs::FieldName('album_artist_raw'));	#AutoFillFields
 	my $hbox= ::Vpack([$label_format,'_',$entry_format],$table,$check_re,[$label_re,'_',$entry_re],$error,$preview,'-',$bbox);
@@ -944,7 +940,6 @@ sub cursor_changed_cb
 
 
 package GMB::TagEdit::EntryString;
-use Gtk2;
 use base 'Gtk2::Entry';
 
 sub new
@@ -965,18 +960,14 @@ sub tool
 }
 
 package GMB::TagEdit::EntryText;
-use Gtk2;
-use base 'Gtk2::VBox';
+use base 'Gtk2::Box';
 
 sub new
 {	my ($class,$field,$IDs) = @_;
 	my $self = bless Gtk2::VBox->new, $class;
-	my $sw = Gtk2::ScrolledWindow->new;
-	 $sw->set_shadow_type('etched-in');
-	 $sw->set_policy('automatic','automatic');
 	my $textview= $self->{textview}= Gtk2::TextView->new;
 	$textview->set_size_request(100,($textview->create_pango_layout("X")->get_pixel_size)[1]*4); #request 4 lines of height
-	$sw->add($textview);
+	my $sw= ::new_scrolledwindow($textview,'etched-in');
 	$self->add($sw);
 	my $val;
 	if (ref $IDs)
@@ -1019,7 +1010,6 @@ sub tool
 }
 
 package GMB::TagEdit::EntryNumber;
-use Gtk2;
 use base 'Gtk2::SpinButton';
 
 sub new
@@ -1088,7 +1078,6 @@ sub output_nozero
 }
 
 package GMB::TagEdit::EntryBoolean;
-use Gtk2;
 use base 'Gtk2::CheckButton';
 
 sub new
@@ -1111,7 +1100,6 @@ sub get_text
 }
 
 package GMB::TagEdit::Combo;
-use Gtk2;
 use base 'Gtk2::Box';
 
 sub new
@@ -1154,8 +1142,7 @@ sub tool
 
 
 package GMB::TagEdit::EntryRating;
-use Gtk2;
-use base 'Gtk2::HBox';
+use base 'Gtk2::Box';
 
 sub new
 {	my ($class,$field,$IDs) = @_;
@@ -1211,7 +1198,6 @@ sub is_blank
 }
 
 package GMB::TagEdit::FlagList;
-use Gtk2;
 use base 'Gtk2::Box';
 
 sub new
@@ -1307,7 +1293,6 @@ sub set_text		# for setting from autofill-from-filename
 }
 
 package GMB::TagEdit::EntryMassList;	#for mass-editing fields with multiple values
-use Gtk2;
 use base 'Gtk2::Box';
 
 sub new
@@ -1435,11 +1420,10 @@ sub set_text		# for setting from autofill-from-filename
 }
 
 package EditTagSimple;
-use Gtk2;
+use base 'Gtk2::Box';
 
 use constant { TRUE  => 1, FALSE => 0, };
 
-use base 'Gtk2::VBox';
 sub new
 {	my ($class,$window,$ID) = @_;
 	my $self = bless Gtk2::VBox->new, $class;
@@ -1527,9 +1511,7 @@ sub save
 ############################## Advanced tag editing ##############################
 
 package EditTag;
-use Gtk2;
-
-use base 'Gtk2::VBox';
+use base 'Gtk2::Box';
 
 sub new
 {	my ($class,$window,$ID) = @_;
@@ -1593,13 +1575,13 @@ sub save
 }
 
 package TagBox;
-use Gtk2;
+use base 'Gtk2::Box';
+
 use constant
 {	TRUE  => 1, FALSE => 0,
 	#contents of types hashes :
 	TAGNAME => 0, TAGORDER => 1, TAGTYPE => 2,
 };
-use base 'Gtk2::VBox';
 
 my %DataType;
 my %tagprop;
@@ -1912,9 +1894,9 @@ sub save
 }
 
 package TagBox_id3v1;
-use Gtk2;
+use base 'Gtk2::Box';
+
 use constant { TRUE  => 1, FALSE => 0 };
-use base 'Gtk2::VBox';
 
 sub new
 {	my ($class,$tag,$option)=@_;
@@ -1968,7 +1950,6 @@ sub save
 }
 
 package EntrySimple;
-use Gtk2;
 use base 'Gtk2::Entry';
 
 sub new
@@ -1989,7 +1970,6 @@ sub return_value
 }
 
 package EntryMultiLines;
-use Gtk2;
 use base 'Gtk2::ScrolledWindow';
 
 sub new
@@ -2021,7 +2001,6 @@ sub return_value
 }
 
 package EntryDouble;
-use Gtk2;
 use base 'Gtk2::Entry';
 
 sub new
@@ -2041,7 +2020,6 @@ sub return_value
 }
 
 package EntryNumber;
-use Gtk2;
 use base 'Gtk2::SpinButton';
 
 sub new
@@ -2060,7 +2038,6 @@ sub return_value
 }
 
 package EntryBoolean;
-use Gtk2;
 use base 'Gtk2::CheckButton';
 
 sub new
@@ -2077,7 +2054,6 @@ sub return_value
 	return $value;
 }
 package EntryCombo;
-use Gtk2;
 use base 'Gtk2::ComboBox';
 
 sub new
@@ -2106,7 +2082,7 @@ sub return_value
 }
 
 package EntryMulti;	#for id3v2 frames containing multiple fields
-use Gtk2;
+use base 'Gtk2::Frame';
 
 my %SUBTAGPROP; my $PICTYPE;
 INIT
@@ -2166,7 +2142,6 @@ INIT
 	);
 	$SUBTAGPROP{metadata_block_picture}=$SUBTAGPROP{APIC}; #for vorbis pictures
 }
-use base 'Gtk2::Frame';
 
 sub new
 {	my ($class,$values,$key,$name,$type,$realkey) = @_;
@@ -2211,7 +2186,6 @@ sub return_value
 }
 
 package EntryBinary;
-use Gtk2;
 use base 'Gtk2::Button';
 
 sub new
@@ -2257,8 +2231,7 @@ sub view
 }
 
 package EntryCover;
-use Gtk2;
-use base 'Gtk2::HBox';
+use base 'Gtk2::Box';
 
 sub new
 {	my $class = shift;
@@ -2325,10 +2298,10 @@ sub set
 	$img->parent->{pixdata}=$self->{value}; #for zoom on click
 }
 sub uri_dropped
-{	my $self=$_[0];
-	my ($file)=split /\x0d\x0a/,$_[2];
-	if ($file=~s#^file://##)
-	{	$self->load_file($file)
+{	my ($self,$type,$uri)=@_;
+	if ($uri=~s#^file://##)
+	{	my $file=::decode_url($uri);
+		$self->load_file($file);
 	}
 	#else #FIXME download http link
 }
@@ -2374,7 +2347,6 @@ sub _identify_pictype	#used only if $Gtk2::VERSION < 1.092
 }
 
 package EntryLyrics;
-use Gtk2;
 use base 'Gtk2::Button';
 
 sub new
