@@ -293,15 +293,15 @@ sub parse_googlei
 	$searchcontext->{baseurl}||= $pageurl;
 	$searchcontext->{pagecount}++;
 	my @list;
-	for my $res (split /<div class="rg_di" *>/, $results)
-	{	next unless $res=~m#&amp;imgurl=(.*?)&amp;#;
+	for my $res (split /<div class="rg_di"[^>]*>/, $results)
+	{	next unless $res=~m#(?:\?|&amp;)imgurl=(.*?)&amp;#;
 		my $url=$1;
 		$url=~s/%([0-9A-Fa-f]{2})/chr hex($1)/gie;
 		#$searchcontext->{rescount}++;
 		my $preview;
-		$preview=$1 if $res=~m/<img class=rg_i [^>]*?src="([^"]+)"/;
+		$preview=$1 if $res=~m/<img class="rg_i" [^>]*?src="([^"]+)"/;
 		my $desc;
-		if ($res=~m/<div class=rg_meta>[^<]*?"pt":"([^"]+)"/)
+		if ($res=~m/<div class="rg_meta">[^<]*?"pt":"([^"]+)"/)
 		{	$desc= ::decode_html(Encode::decode('utf8',$1));
 			$desc=~s#</?b>##g;
 		}
@@ -479,6 +479,7 @@ sub get_next
 					  $loader->get_format->{extensions}[0]
 					: ( EntryCover::_identify_pictype($pixdata) )[0];
 			$button->{ext}='jpg' if $button->{ext} eq 'jpeg';
+			$button->{url}= $result->{url};
 			my $vbox=Gtk2::VBox->new(0,0);
 			my $label=Gtk2::Label->new($dim);
 			$vbox->add($image);
@@ -491,6 +492,7 @@ sub get_next
 			$button->set_tooltip_markup($tip);
 			$button->signal_connect(clicked => \&set_cover);
 			$button->signal_connect(button_press_event => \&GMB::Picture::pixbox_button_press_cb,3); # 3 : mouse button 3
+			::set_drag($button, source=> [::DRAG_FILE,sub { return ::DRAG_FILE,$_[0]{url} }]);
 			$button->set_relief('none');
 			$button->show_all;
 			my $i= $res_id % RES_PER_PAGE;
@@ -528,7 +530,7 @@ sub set_cover
 	$check->set_active(1);
 	my $default_file=	$::Options{OPT.'USEFILE'} ?
 				$::Options{OPT.'COVERFILE'} : $name;
-	$default_file=~s/\.(?:jpe?g|png|gif)$//;
+	$default_file=~s/$::Image_ext_re//;
 	$default_file.='.'.$button->{ext};
 	$default_file=::filename_from_unicode(::CleanupFileName($default_file));
 	my $default_dir=$::Options{OPT.'COVERPATH'} || '';
