@@ -74,9 +74,9 @@ sub about_to_load_cb	#called before loading a new uri,
 }
 
 sub loaded
-{	my ($self,$data,$type)=@_;
+{	my ($self,$data,%prop)=@_;
 	my $embed=$self->{embed};
-	$embed->render_data($data,$self->{url},$type)
+	$embed->render_data($data,$self->{url},$prop{type});
 #	$embed->open_stream ($self->{url}, $type);
 #	$embed->append_data ($data);
 #	$embed->close_stream;
@@ -156,9 +156,9 @@ sub net_startstop_cb
 sub set_title {} #ignored unless overridden by the class
 
 sub loaded
-{	my ($self,$data,$type)=@_;
+{	my ($self,$data,%prop)=@_;
 	my $embed=$self->{embed};
-	$embed->load_html_string($data,$self->{url}); #FIXME doesn't check type
+	$embed->load_html_string($data,$self->{url}); #FIXME doesn't check type ($prop{type})
 }
 
 
@@ -228,12 +228,12 @@ our %Widgets=
 our @default_options= (follow=>1, urientry=>1, statusbar=>0, );
 our @contextmenu=
 (	{	label=> _"Show/hide URI entry",
-		check => sub { $_[0]{self}{urientry} },
-		code => sub { my $w=$_[0]{self}{Entry}; if ($_[0]{self}{urientry}^=1) { $w->set_no_show_all(0); $w->show_all; } else { $w->hide; }  },
+		toggleoption=> 'self/urientry',
+		code => sub { my $w=$_[0]{self}{Entry}; if ($_[0]{self}{urientry}) { $w->set_no_show_all(0); $w->show_all; } else { $w->hide; }  },
 	},
 	{	label=> _"Show/hide status bar",
-		check => sub { $_[0]{self}{statusbar} },
-		code => sub { my $w=$_[0]{self}{Status}; if ($_[0]{self}{statusbar}^=1) { $w->set_no_show_all(0); $w->show_all; } else { $w->hide; }  },
+		toggleoption=> 'self/statusbar',
+		code => sub { my $w=$_[0]{self}{Status}; if ($_[0]{self}{statusbar}) { $w->set_no_show_all(0); $w->show_all; } else { $w->hide; }  },
 	},
 );
 
@@ -560,10 +560,10 @@ sub wikiload	#not used for now
 }
 
 sub wikifilter	#not used for now
-{	my ($self,$data,$type)=@_;
+{	my ($self,$data,%prop)=@_;
 	return unless $data;	#FIXME
 	#$data='<style type="text/css">.firstHeading {display: none}</style>'.$data;
-	$self->loaded($data,$type);
+	$self->loaded($data,%prop);
 }
 
 package GMB::Plugin::WebContext::Custom;
@@ -583,8 +583,7 @@ sub SongChanged
 
 
 package GMB::Plugin::WebContext::Custom::Edition;
-use Gtk2;
-use base 'Gtk2::VBox';
+use base 'Gtk2::Box';
 
 my $CustomPages= $::Options{GMB::Plugin::WebContext::OPT.'Custom'};
 
